import type * as React from 'react';
import type { BaseSelectFieldProps } from './selectField';
import type { BaseTextFieldProps } from './textField';
import type { ElementType, PrimitiveProps } from './view';
interface optionalPhoneNumberFieldProps extends BaseTextFieldProps, CountryCodeFieldProps {
    /**
     * @description
     * Sets a hidden and accessible label for the dial code selector
     */
    dialCodeLabel?: string;
    /**
     * @description
     * Sets the name used when handling form submission for the dial code selector
     */
    dialCodeName?: string;
    /**
     * @description
     * Accepts an array of dial codes (strings) used as options in the dial code selector
     */
    dialCodeList?: Array<string>;
    /**
     * @description
     * Handles change events for the dial code selector
     */
    onDialCodeChange?: React.ChangeEventHandler<HTMLSelectElement>;
    /**
     * @description
     * <input> elements of type 'tel' are used to let the user enter and edit a telephone number
     */
    type?: 'tel';
    /**
     * @description
     * Forwarded ref for access to Dial Code select DOM element
     */
    dialCodeRef?: React.Ref<HTMLSelectElement>;
}
interface CountryCodeFieldProps {
    /**
     * @description
     * Sets a hidden and accessible label for the dial code selector
     * @deprecated
     * To be removed with next major version release, please use dialCodeLabel
     */
    countryCodeLabel?: string;
    /**
     * @description
     * Sets the name used when handling form submission for the dial code selector
     * @deprecated
     * To be removed with next major version release, please use dialCodeName
     */
    countryCodeName?: string;
    /**
     * @description
     * Handles change events for the dial code selector
     * @deprecated
     * To be removed with next major version release, please use onDialCodeChange
     */
    onCountryCodeChange?: React.ChangeEventHandler<HTMLSelectElement>;
    /**
     * @description
     * Forwarded ref for access to Country Code select DOM element
     * @deprecated
     * To be removed with next major version release, please use dialCodeRef
     */
    countryCodeRef?: React.Ref<HTMLSelectElement>;
}
interface CountryCodeRequired extends optionalPhoneNumberFieldProps {
    /**
     * @description
     * Sets the default dial code that will be selected on initial render
     * @deprecated
     * To be removed with next major version release, please use defaultDialCode
     */
    defaultCountryCode: string;
    /**
     * @description
     * Sets the default dial code that will be selected on initial render
     */
    defaultDialCode?: string;
}
interface DialCodeRequired extends optionalPhoneNumberFieldProps {
    /**
     * @description
     * Sets the default dial code that will be selected on initial render
     * @deprecated
     * To be removed with next major version release, please use defaultDialCode
     */
    defaultCountryCode?: string;
    /**
     * @description
     * Sets the default dial code that will be selected on initial render
     */
    defaultDialCode: string;
}
/** @deprecated For internal use only */
export type BasePhoneNumberFieldProps = CountryCodeRequired | DialCodeRequired;
export type PhoneNumberFieldProps<Element extends ElementType = 'input'> = PrimitiveProps<BasePhoneNumberFieldProps, Element>;
/** @deprecated For internal use only */
export interface BaseDialCodeSelectProps extends BaseSelectFieldProps {
    defaultValue?: string;
    dialCodeList?: Array<string>;
    isReadOnly?: boolean;
}
export type DialCodeSelectProps<Element extends ElementType = 'select'> = PrimitiveProps<BaseDialCodeSelectProps, Element>;
export {};
